Documentation
¶
Index ¶
- type Query
- func (q *Query) And(condition string, options ...whereOption) whereCondition
- func (q *Query) Distinct() *Query
- func (q *Query) DistinctOn(columns ...string) *Query
- func (q *Query) For(lock string) *Query
- func (q *Query) GroupBy(columns ...string) *Query
- func (q *Query) Limit(count uint64) *Query
- func (q *Query) Offset(start uint64) *Query
- func (q *Query) Or(condition string, options ...whereOption) whereCondition
- func (q *Query) OrderBy(expression string, options ...string) *Query
- func (q *Query) Param(v ...interface{}) parameterOption
- func (q Query) Parameters() []interface{}
- func (q *Query) Returning(columns ...string) *Query
- func (q *Query) Select(columns ...string) *Query
- func (q *Query) Set(set string, params ...interface{}) *Query
- func (q Query) String() string
- func (q *Query) Values(params ...interface{}) *Query
- func (q *Query) Where(condition string, options ...whereOption) *Query
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Query ¶
type Query struct {
// contains filtered or unexported fields
}
func (*Query) Distinct ¶
Distinct excludes all duplicate rows from the result set. One row will be kept from each group of duplicates.
func (*Query) DistinctOn ¶
DistinctOn keeps only the first row of each set of rows where the given expressions evaluate to equal.
func (*Query) GroupBy ¶
GroupBy groups together those rows in a table that have the same values in all the columns listed.
func (*Query) Param ¶
func (q *Query) Param(v ...interface{}) parameterOption
Param registers one or more parameters to this query. You can use Parameters to get all of them.
func (Query) Parameters ¶
func (q Query) Parameters() []interface{}
Parameters returns all parameters in this query.
Click to show internal directories.
Click to hide internal directories.